/** WebsaverDialogSave.java
 *
 *  @author Brad Fitzpatrick, bradfitz@bradfitz.com
 */

import java.awt.*;
import java.awt.event.*;
import java.util.Vector;
import java.util.Hashtable;

public class WebsaverDialogSave extends Frame implements ActionListener, WindowListener 
{
    private Button btnSave = new Button("Save");
    private TextField txtFile = new TextField(25);
    private TextField txtPassword = new TextField(10);
    boolean showPassword;
    private WebsaverConnection wsConn;
    private Vector listeners;

    public WebsaverDialogSave (WebsaverConnection conn)
    {
	this(conn, false);
    }

    public WebsaverDialogSave (WebsaverConnection conn, boolean showPassword)
    {
	super("Save File");

	txtPassword.setEchoChar('*');
	this.wsConn = conn;
	this.showPassword = showPassword;
	listeners = new Vector();
	
	Panel buttonPanel = new Panel();
	buttonPanel.setLayout(new FlowLayout());
	if (showPassword) {
	    buttonPanel.add(new Label("Resave Password:"));
	    buttonPanel.add(txtPassword);
	}
	buttonPanel.add(btnSave);

	Panel savePanel = new Panel();
	savePanel.setLayout(new FlowLayout());
	savePanel.add(new Label("Save as:"));
	savePanel.add(txtFile);
	
	add("South", buttonPanel);
	add("Center", savePanel);

	btnSave.addActionListener(this);
	addWindowListener(this);
    }

    /** Shows the Dialog, centered over component cpt. */
    public void showDialog (Component cpt)
    {
	// parent location and dimension
	Dimension pd = cpt.getSize();
	Point pl = cpt.getLocationOnScreen();

	// this dimension and location
	Dimension td = new Dimension(400, 150);
	Point tl = new Point(pl.x + (pd.width-td.width)/2, pl.y + (pd.height-td.height)/2);

	setSize(td);
	setLocation(tl);

	setVisible(true);
	toFront();
    }

    /** Hides the dialog */
    public void hideDialog ()
    {
	setVisible(false);
    }

    /** Set the text to save as */
    public void setFilename (String s)
    {
	txtFile.setText(s);
    }

    /** Call this to register a listener for when somebody presses Save */
    public void addWebsaverDialogListener (WebsaverDialogListener wdl)
    {
	listeners.addElement(wdl);
    }

    public void actionPerformed(ActionEvent evt)
    {
	Object source = evt.getSource();
	if ((Button)source == btnSave) {
	    String filename = txtFile.getText();
	    if (filename.length() > 0) {
		// dispatch events!
		for (int i=0; i<listeners.size(); i++) {
		    WebsaverDialogListener wdl = (WebsaverDialogListener) listeners.elementAt(i);
		    WebsaverDialogEvent wde = new WebsaverDialogEvent(wsConn, filename, showPassword ? txtPassword.getText() : null);
		    wdl.websaverFileSave(wde);
		}
	    }
	} // end btnSave
    }

    public void windowOpened(WindowEvent e)
    {
    }

    public void windowClosing(WindowEvent e)
    {
	setVisible(false);
    }

    public void windowClosed(WindowEvent e)
    {
    }

    public void windowIconified(WindowEvent e)
    {
    }

    public void windowDeiconified(WindowEvent e)
    {
    }

    public void windowActivated(WindowEvent e)
    {
    }

    public void windowDeactivated(WindowEvent e)
    {
    }

}
